@@ -48,6 +48,9 @@ namespace GtkSharp.Generation {
 				if (p.CType == "GError**")
 					continue;
 
+				if (p.Scope == "notified")
+					i += 2;
+
 				this.parms.Add (p);
 			}
 		}
@@ -62,8 +65,6 @@ namespace GtkSharp.Generation {
 
 			foreach (Parameter p in parms) {
 				result [i] = p.PassAs != "" ? p.PassAs + " " : "";
-				if (p.Generatable is StructGen)
-					result [i] += "ref ";
 				result [i++] += p.CSType + " " + p.Name;
 			}
 
