@@ -24,7 +24,6 @@ namespace GLib {
 
 	using System;
 	using System.Collections;
-	using System.Reflection;
 	using System.Runtime.InteropServices;
 
 	[StructLayout (LayoutKind.Sequential)]
@@ -58,16 +57,6 @@ namespace GLib {
 			g_value_set_boolean (ref this, val);
 		}
 
-		public Value (byte val) : this (GType.UChar)
-		{
-			g_value_set_uchar (ref this, val);
-		}
-
-		public Value (sbyte val) : this (GType.Char)
-		{
-			g_value_set_char (ref this, val);
-		}
-
 		public Value (int val) : this (GType.Int)
 		{
 			g_value_set_int (ref this, val);
@@ -158,13 +147,6 @@ namespace GLib {
 			GLib.Marshaller.Free (prop);
 		}
 
-		internal Value (GLib.Object obj, IntPtr prop)
-		{
-			type = IntPtr.Zero;
-			pad_1 = pad_2 = 0;
-			gtksharp_value_create_from_property (ref this, obj.Handle, prop);
-		}
-
 		[Obsolete]
 		public Value (GLib.Object obj, string prop_name, EnumWrapper wrap)
 		{
@@ -226,16 +208,6 @@ namespace GLib {
 			return g_value_get_boolean (ref val);
 		}
 
-		public static explicit operator byte (Value val)
-		{
-			return g_value_get_uchar (ref val);
-		}
-
-		public static explicit operator sbyte (Value val)
-		{
-			return g_value_get_char (ref val);
-		}
-
 		public static explicit operator int (Value val)
 		{
 			return g_value_get_int (ref val);
@@ -341,14 +313,7 @@ namespace GLib {
 			Type t = GType.LookupType (type);
 			if (t == null)
 				throw new Exception ("Unknown type " + new GType (type).ToString ());
-			else if (t.IsSubclassOf (typeof (GLib.Opaque)))
-				return (GLib.Opaque) this;
-
-			MethodInfo mi = t.GetMethod ("New", BindingFlags.Static | BindingFlags.Public | BindingFlags.FlattenHierarchy);
-			if (mi == null)
-				return Marshal.PtrToStructure (boxed_ptr, t);
-			else
-				return mi.Invoke (null, new object[] {boxed_ptr});
+			return Marshal.PtrToStructure (boxed_ptr, t);
 		}
 
 		public object Val
@@ -356,10 +321,6 @@ namespace GLib {
 			get {
 				if (type == GType.Boolean.Val)
 					return (bool) this;
-				else if (type == GType.UChar.Val)
-					return (byte) this;
-				else if (type == GType.Char.Val)
-					return (sbyte) this;
 				else if (type == GType.Int.Val)
 					return (int) this;
 				else if (type == GType.UInt.Val)
@@ -379,26 +340,18 @@ namespace GLib {
 					return (string) this;
 				else if (type == GType.Pointer.Val)
 					return (IntPtr) this;
-				else if (type == GType.Param.Val)
-					return g_value_get_param (ref this);
 				else if (type == ManagedValue.GType.Val)
 					return ManagedValue.ObjectForWrapper (g_value_get_boxed (ref this));
 				else if (g_type_is_a (type, GType.Object.Val))
 					return (GLib.Object) this;
 				else if (g_type_is_a (type, GType.Boxed.Val))
 					return ToBoxed ();
-				else if (type == IntPtr.Zero)
-					return null;
 				else
 					throw new Exception ("Unknown type " + new GType (type).ToString ());
 			}
 			set {
 				if (type == GType.Boolean.Val)
 					g_value_set_boolean (ref this, (bool) value);
-				else if (type == GType.UChar.Val)
-					g_value_set_uchar (ref this, (byte) value);
-				else if (type == GType.Char.Val)
-					g_value_set_char (ref this, (sbyte) value);
 				else if (type == GType.Int.Val)
 					g_value_set_int (ref this, (int) value);
 				else if (type == GType.UInt.Val)
@@ -420,27 +373,19 @@ namespace GLib {
 					g_value_set_string (ref this, native);
 					GLib.Marshaller.Free (native);
 				} else if (type == GType.Pointer.Val) {
-					if (value is IntPtr) {
-						g_value_set_pointer (ref this, (IntPtr) value);
-						return;
-					} else if (value is IWrapper) {
+					if (value is IWrapper) {
 						g_value_set_pointer (ref this, ((IWrapper)value).Handle);
 						return;
 					}
 					IntPtr buf = Marshal.AllocHGlobal (Marshal.SizeOf (value.GetType()));
 					Marshal.StructureToPtr (value, buf, false);
 					g_value_set_pointer (ref this, buf);
-				} else if (type == GType.Param.Val) {
-					g_value_set_param (ref this, (IntPtr) value);
 				} else if (type == ManagedValue.GType.Val) {
 					IntPtr wrapper = ManagedValue.WrapObject (value);
 					g_value_set_boxed (ref this, wrapper);
 					ManagedValue.ReleaseWrapper (wrapper);
 				} else if (g_type_is_a (type, GType.Object.Val))
-					if(value is GLib.Object)
-						g_value_set_object (ref this, (value as GLib.Object).Handle);
-					else
-						g_value_set_object (ref this, (value as GLib.GInterfaceAdapter).Handle);
+					g_value_set_object (ref this, ((GLib.Object) value).Handle);
 				else if (g_type_is_a (type, GType.Boxed.Val)) {
 					if (value is IWrapper) {
 						g_value_set_boxed (ref this, ((IWrapper)value).Handle);
@@ -454,127 +399,103 @@ namespace GLib {
 			}
 		}
 
-		internal void Update (object val)
-		{
-			if (g_type_is_a (type, GType.Boxed.Val) && !(val is IWrapper))
-				Marshal.StructureToPtr (val, g_value_get_boxed (ref this), false);
-		}
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_init (ref GLib.Value val, IntPtr gtype);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_unset (ref GLib.Value val);
 
-		[DllImport("glibsharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("glibsharpglue-2")]
 		static extern IntPtr gtksharp_value_create_from_property(ref GLib.Value val, IntPtr obj, IntPtr name);
 
-		[DllImport("glibsharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("glibsharpglue-2")]
 		static extern IntPtr gtksharp_value_create_from_type_and_property(ref GLib.Value val, IntPtr gtype, IntPtr name);
 
-		[DllImport("glibsharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("glibsharpglue-2")]
 		static extern IntPtr gtksharp_value_create_from_type_name(ref GLib.Value val, IntPtr type_name);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_boolean (ref Value val, bool data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern void g_value_set_uchar (ref Value val, byte data);
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern void g_value_set_char (ref Value val, sbyte data);
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_boxed (ref Value val, IntPtr data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_double (ref Value val, double data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_float (ref Value val, float data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_int (ref Value val, int data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_int64 (ref Value val, long data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_uint64 (ref Value val, ulong data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_object (ref Value val, IntPtr data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern void g_value_set_param (ref Value val, IntPtr data);
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_pointer (ref Value val, IntPtr data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_string (ref Value val, IntPtr data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_uint (ref Value val, uint data);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_enum (ref Value val, int data);
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern void g_value_set_flags (ref Value val, uint data);
 		
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern bool g_value_get_boolean (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern byte g_value_get_uchar (ref Value val);
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern sbyte g_value_get_char (ref Value val);
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern IntPtr g_value_get_boxed (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern double g_value_get_double (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern float g_value_get_float (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern int g_value_get_int (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern long g_value_get_int64 (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern ulong g_value_get_uint64 (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern IntPtr g_value_get_object (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern IntPtr g_value_get_param (ref Value val);
-
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern IntPtr g_value_get_pointer (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern IntPtr g_value_get_string (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern uint g_value_get_uint (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern int g_value_get_enum (ref Value val);
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern uint g_value_get_flags (ref Value val);
-		[DllImport("glibsharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("glibsharpglue-2")]
 		static extern bool glibsharp_value_holds_flags (ref Value val);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern bool g_type_is_a (IntPtr type, IntPtr is_a_type);
 
-		[DllImport("libgobject-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libgobject-2.0-0.dll")]
 		static extern IntPtr g_strv_get_type ();
 	}
 }
